@@ -31,50 +31,50 @@
 // SMI trap oid def
 class snmpTrapsOid: public Oid {
 public:
-  snmpTrapsOid (void):Oid("1.3.6.1.6.3.1.1.5"){};
+  snmpTrapsOid ():Oid("1.3.6.1.6.3.1.1.5"){};
 };
 
 // SMI Enterprose Oid
 class snmpTrapEnterpriseOid: public Oid {
 public:
-  snmpTrapEnterpriseOid(void):Oid("1.3.6.1.6.3.1.1.4.3.0"){};
+  snmpTrapEnterpriseOid():Oid("1.3.6.1.6.3.1.1.4.3.0"){};
 };
 
 // SMI Cold Start Oid
 class coldStartOid: public snmpTrapsOid {
 public:
-  coldStartOid( void){*this+=".1";};
+  coldStartOid(){*this+=".1";};
 };
 
 // SMI WarmStart Oid
 class warmStartOid: public snmpTrapsOid {
 public:
-  warmStartOid( void){*this+=".2";};
+  warmStartOid(){*this+=".2";};
 };
 
 // SMI LinkDown Oid
 class linkDownOid: public snmpTrapsOid {
 public:
-  linkDownOid( void){*this+=".3";};
+  linkDownOid(){*this+=".3";};
 };
 
 
 // SMI LinkUp Oid
 class linkUpOid: public snmpTrapsOid {
 public:
-  linkUpOid( void){*this+=".4";};
+  linkUpOid(){*this+=".4";};
 };
 
 // SMI Authentication Failure Oid
 class authenticationFailureOid: public snmpTrapsOid {
 public:
-  authenticationFailureOid( void){*this+=".5";};
+  authenticationFailureOid(){*this+=".5";};
 };
 
 // SMI egpneighborloss Oid
 class egpNeighborLossOid: public snmpTrapsOid {
 public:
-  egpNeighborLossOid( void){*this+=".6";};
+  egpNeighborLossOid(){*this+=".6";};
 };
 
 
