@@ -97,11 +97,11 @@ char ACE_ALPHABET[] = "abcdefghijklmnopqrstuvwxyz";
 class ACE_Test_Output
 {
 public:
-  ACE_Test_Output (void);
-  ~ACE_Test_Output (void);
+  ACE_Test_Output ();
+  ~ACE_Test_Output ();
   int set_output (const ACE_TCHAR *filename, int append = 0);
-  ofstream *output_file (void);
-  void close (void);
+  ofstream *output_file ();
+  void close ();
 
 private:
   ofstream output_file_;
@@ -109,11 +109,11 @@ private:
 
 static ACE_Test_Output ace_file_stream;
 
-ACE_Test_Output::ACE_Test_Output (void)
+ACE_Test_Output::ACE_Test_Output ()
 {
 }
 
-ACE_Test_Output::~ACE_Test_Output (void)
+ACE_Test_Output::~ACE_Test_Output ()
 {
 }
 
@@ -140,13 +140,13 @@ ACE_Test_Output::set_output (const ACE_TCHAR *filename, int append)
 }
 
 ofstream *
-ACE_Test_Output::output_file (void)
+ACE_Test_Output::output_file ()
 {
   return &this->output_file_;
 }
 
 void
-ACE_Test_Output::close (void)
+ACE_Test_Output::close ()
 {
   this->output_file_.flush ();
   this->output_file_.close ();
