@@ -4,8 +4,6 @@
 /**
  *  @file    DLL.h
  *
- *  $Id: DLL.h 97443 2013-12-02 10:10:34Z johnnyw $
- *
  *  @author Kirthika Parameswaran <kirthika@cs.wustl.edu>
  */
 //=============================================================================
@@ -22,6 +20,7 @@
 
 #include "ace/Global_Macros.h"
 #include "ace/os_include/os_dlfcn.h"
+#include "ace/SString.h"
 
 ACE_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -42,8 +41,6 @@ class ACE_DLL_Handle;
 class ACE_Export ACE_DLL
 {
 public:
-  // = Initialization and termination methods.
-
   /**
    * Default constructor.  By default, the close() operation on the
    * object will be invoked before it is destroyed.
@@ -134,14 +131,14 @@ public:
             bool close_handle_on_destruction = true);
 
   /// Call to close the DLL object.
-  int close (void);
+  int close ();
 
   /**
    * Called when the DLL object is destroyed -- invokes close() if the
    * @a close_handle_on_destruction flag was set to non-zero in the
    * constructor or open() method.
    */
-  ~ACE_DLL (void);
+  ~ACE_DLL ();
 
   /**
    * Look up a named symbol in the DLL. DLL must be successfully opened
@@ -155,10 +152,10 @@ public:
    */
   void *symbol (const ACE_TCHAR *symbol_name, int ignore_errors = 0);
 
-  /// Returns a pointer to a string explaining that an error occured.  You
+  /// Returns a pointer to a string explaining that an error occurred.  You
   /// will need to consult the error log for the actual error string
   /// returned by the OS.
-  ACE_TCHAR *error (void) const;
+  ACE_TCHAR *error () const;
 
   /**
    * Return the handle to the caller.  If @a become_owner is true then
@@ -174,16 +171,13 @@ public:
                   bool close_handle_on_destruction = true);
 
 private:
-
   int open_i (const ACE_TCHAR *dll_name,
               int open_mode = ACE_DEFAULT_SHLIB_MODE,
               bool close_handle_on_destruction = true,
               ACE_SHLIB_HANDLE handle = 0);
 
 
-  //private:
 public:
-
   /// Open mode.
   int open_mode_;
 
@@ -200,6 +194,9 @@ public:
 
   /// Flag to record if the last operation had an error.
   bool error_;
+
+  /// Any error messages encountered during last operation.
+  ACE_TString errmsg_;
 };
 
 ACE_END_VERSIONED_NAMESPACE_DECL
