@@ -8,24 +8,24 @@ class Map_Example
 {
 public:
   // Illustrate the ACE_Map_Manager.
-  int run (void);
+  int run ();
 
 private:
   // Iterate in the forward direction.
-  void iterate_forward (void);
+  void iterate_forward ();
 
   // Iterate in the other direction.
-  void iterate_reverse (void);
+  void iterate_reverse ();
 
   // Remove all elements from the map.
-  void remove_all (void);
+  void remove_all ();
 
 private:
   ACE_Map_Manager<KeyType,DataElement,ACE_Null_Mutex> map_;
 };
 
 // Listing 2 code/ch05
-int Map_Example::run (void)
+int Map_Example::run ()
 {
   ACE_TRACE ("Map_Example::run");
 
@@ -60,7 +60,7 @@ int Map_Example::run (void)
 }
 // Listing 2
 // Listing 3 code/ch05
-void Map_Example::iterate_forward (void)
+void Map_Example::iterate_forward ()
 {
   ACE_TRACE ("Map_Example::iterate_forward");
 
@@ -79,7 +79,7 @@ void Map_Example::iterate_forward (void)
 }
 
 
-void Map_Example::iterate_reverse (void)
+void Map_Example::iterate_reverse ()
 {
   ACE_TRACE ("Map_Example::iterate_reverse");
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("Reverse iteration\n")));
@@ -97,7 +97,7 @@ void Map_Example::iterate_reverse (void)
 }
 // Listing 3
 // Listing 4 code/ch05
-void Map_Example::remove_all (void)
+void Map_Example::remove_all ()
 {
   ACE_TRACE ("Map_Example::remove_all");
 
