@@ -18,17 +18,17 @@ class Tree_Example
 {
 public:
   // Illustrate the tree.
-  int run (void);
+  int run ();
 
 private:
   // Use the forward iterator.
-  void iterate_forward (void);
+  void iterate_forward ();
 
   // Use the reverse iterator.
-  void iterate_reverse (void);
+  void iterate_reverse ();
 
   // Remove all elements from the tree.
-  int remove_all (void);
+  int remove_all ();
 
 private:
   Tree<KeyType, DataElement*> tree_;
@@ -78,7 +78,7 @@ int Tree_Example::run ()
   return 0;
 }
 
-void Tree_Example::iterate_forward (void)
+void Tree_Example::iterate_forward ()
 {
   ACE_TRACE ("Tree_Example::iterate_forward");
 
@@ -91,7 +91,7 @@ void Tree_Example::iterate_forward (void)
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("\n")));
 }
 
-void Tree_Example::iterate_reverse (void)
+void Tree_Example::iterate_reverse ()
 {
   ACE_TRACE ("Tree_Example::iterate_reverse");
 
@@ -104,7 +104,7 @@ void Tree_Example::iterate_reverse (void)
   ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("\n")));
 }
 
-int Tree_Example::remove_all (void)
+int Tree_Example::remove_all ()
 {
   ACE_TRACE ("Tree_Example::remove_all");
 
