@@ -1,8 +1,6 @@
-// $Id: Simple1.cpp 91813 2010-09-17 07:52:52Z johnnyw $
-
 #include "ace/Log_Msg.h"
 
-void foo (void);
+void foo ();
 
 int ACE_TMAIN (int, ACE_TCHAR *[])
 {
@@ -15,7 +13,7 @@ int ACE_TMAIN (int, ACE_TCHAR *[])
   return 0;
 }
 
-void foo (void)
+void foo ()
 {
   ACE_TRACE ("foo");
 
