@@ -1,7 +1,7 @@
 #include "LogManager.h"
 
 // Listing 1 code/ch03
-void foo (void);
+void foo ();
 
 int ACE_TMAIN (int, ACE_TCHAR *[])
 {
@@ -15,7 +15,7 @@ int ACE_TMAIN (int, ACE_TCHAR *[])
 
   return 0;
 }
-void foo (void)
+void foo ()
 {
   ACE_TRACE ("foo");
   LOG_MANAGER->redirectToFile ("output.test");
