@@ -10,7 +10,7 @@ CommandModule::CommandModule (const ACE_TCHAR *module_name,
 // Listing 01
 
 // Listing 02 code/ch18
-ACE_SOCK_Stream &CommandModule::peer (void)
+ACE_SOCK_Stream &CommandModule::peer ()
 {
   ACE_SOCK_Stream *peer = (ACE_SOCK_Stream *)this->arg ();
   return *peer;
