@@ -16,12 +16,6 @@ public:
                           ACE_Reactor *reactor);
 };
 
-#if defined (ACE_TEMPLATES_REQUIRE_SOURCE)
 #include "Reactor_Logging_Server_T.cpp"
-#endif /* ACE_TEMPLATES_REQUIRE_SOURCE */
-
-#if defined (ACE_TEMPLATES_REQUIRE_PRAGMA)
-#pragma implementation ("Reactor_Logging_Server_T.cpp")
-#endif /* ACE_TEMPLATES_REQUIRE_PRAGMA */
 
 #endif /* _REACTOR_LOGGING_SERVER_T_H */
